@@ -1,3 +1,5 @@
+DEBUG = False
+
 from platform import platform
 import docker
 import requests
@@ -9,6 +11,11 @@ import sys
 from time import sleep
 import logging
 
+if DEBUG:
+    import localCloudFunctions.createDeploymentService as createDeploymentService
+    import localCloudFunctions.writeModels as writeModelFunction
+    import localCloudFunctions.createRepo as createRepoFunction
+
 project_name = "knuth33"
 docker_artifact_repository_loc = "us-central1-docker.pkg.dev"
 
@@ -34,8 +41,10 @@ CMD ["uvicorn", "main:app", "--host", "0.0.0.0", "--port", "8080"]
     with open(app_folder_path+ "/Dockerfile", 'w') as f:
         f.write(docker_string)
 
-def stringTester(testString):
-    matched = re.fullmatch('[a-z0-9]([-a-z0-9]*[a-z0-9])', testString)
+def check_string(testString):
+    # NOTE: the regex for pods and for services are different.  services are more restrictive (have to start with a letter)
+    # so that is the one we are using here.
+    matched = re.fullmatch('[a-z]([-a-z0-9]*[a-z0-9])', testString)
     return(bool(matched))
 
 # NOTE: requirements is an optional parameter - if you specify it, we won't make you one. Also note that if we make one it'll
@@ -44,6 +53,7 @@ def deployModel(model_name, version_name, project_directory, number_pods, requir
     # TODO: consider doing this AFTER we successfully upload the model
     # TODO: look up model type 
     # TODO: return namespace name when we write it successfully
+
     try:
         homeDir = os.path.expanduser( '~' )
         f = open(f"{homeDir}/pyqai.config")
@@ -86,8 +96,12 @@ def deployModel(model_name, version_name, project_directory, number_pods, requir
         getTokenJson = json.loads(getToken.text)
         getTokenResponse = getTokenJson["response"]
 
-        gcp_token = getTokenResponse
-        os.environ["GOOGLE_APPLICATION_CREDENTIALS"]=json.dumps(gcp_token)
+        if not DEBUG:
+            gcp_token = getTokenResponse
+            os.environ["GOOGLE_APPLICATION_CREDENTIALS"]=json.dumps(gcp_token)
+        else:
+            with open("gcp_token.json", "r") as read_file:
+                gcp_token = json.load(read_file)
 
         if(getToken.status_code != 200):
             printError(f"ERROR. Deployment failed. Authentication failed with error code: {getToken.status_code} and message: {getTokenResponse}")
@@ -102,24 +116,29 @@ def deployModel(model_name, version_name, project_directory, number_pods, requir
 
 #region Namespace creation
     requestBodyWriteModel = {"account_id": account_id, "account_name": account_name, "model_name" : model_name, "model_type" : 1}
-    writeModels = requests.post('https://write-models-fgkue36c2q-uc.a.run.app', json = requestBodyWriteModel, headers={'Authorization': api_token})
-
-    model_id = ''
 
     try:
-        writeModelsJson = json.loads(writeModels.text)
-        writeModelsResponse = writeModelsJson["response"]
-        if verbose_logging : printInfo("Write models reponse: " + writeModels.text)
+        if not DEBUG:
+            writeModels = requests.post('https://write-models-fgkue36c2q-uc.a.run.app', json = requestBodyWriteModel, headers={'Authorization': api_token})
+       
+            writeModelsJson = json.loads(writeModels.text)
+            writeModelsResponse = writeModelsJson["response"]
+            if verbose_logging : printInfo("Write models reponse: " + writeModels.text)
+
+            model_id = writeModelsResponse
+
+            if(writeModels.status_code != 200):
+                printError(f"ERROR. Deployment failed. Attempt to create user namespace failed with error code: {writeModels.status_code} and message: {writeModelsResponse}")
+                return
+        else:
+            writeModels = writeModelFunction.createModelTest(requestBodyWriteModel, api_token)
+            model_id = writeModels[0]["response"]
 
-        model_id = writeModelsResponse
         if verbose_logging : printInfo("Model id: " + str(model_id))
 
-        if(writeModels.status_code != 200):
-            printError(f"ERROR. Deployment failed. Attempt to create user namespace failed with error code: {writeModels.status_code} and message: {writeModelsResponse}")
-            return
     except Exception as e:
         logging.error(e, exc_info=True)
-        printError(f"ERROR. Deployment failed. Attempt to create user namespace failed with error: {writeModels.text} {e}")
+        printError(f"ERROR. Deployment failed. Attempt to create user namespace failed with error: {e}")
         return
 #endregion
 
@@ -162,17 +181,23 @@ def deployModel(model_name, version_name, project_directory, number_pods, requir
 
 #region create/get user artifact registry
     # Get this users repository, if it doesn't exist this funciton will create it.
-    requestBodyCreateRepo = {"account_id": account_id}
-    callCreateRepo = requests.post('https://create-repo-fgkue36c2q-uc.a.run.app', json = requestBodyCreateRepo, headers={'Authorization': api_token})       
-    repo_location = ""
     try: 
-        json_repo = json.loads(callCreateRepo.text)
-        repo_location = json_repo["response"]
-        if verbose_logging : printInfo("Create repository response: " + callCreateRepo.text)
+        requestBodyCreateRepo = {"account_id": account_id}
+        if not DEBUG:
+            callCreateRepo = requests.post('https://create-repo-fgkue36c2q-uc.a.run.app', json = requestBodyCreateRepo, headers={'Authorization': api_token})
 
-        if(callCreateRepo.status_code != 200):
-            printError(f"ERROR. Deployment failed. Attempt to create artifact repository failed with error code: {callCreateRepo.status_code} and message: {repo_location}")
-            return
+            json_repo = json.loads(callCreateRepo.text)
+            repo_location = json_repo["response"]
+            if verbose_logging : printInfo("Create repository response: " + callCreateRepo.text)
+
+            if(callCreateRepo.status_code != 200):
+                printError(f"ERROR. Deployment failed. Attempt to create artifact repository failed with error code: {callCreateRepo.status_code} and message: {repo_location}")
+                return
+        else:
+            callCreateRepo = createRepoFunction.getRepoNameTest(requestBodyCreateRepo, api_token)
+            repo_location = callCreateRepo[0]["response"]
+
+            if verbose_logging : printInfo("Create repository response: " + repo_location)
     except Exception as e:
             logging.error(e, exc_info=True)
             printError(f"ERROR. Deployment failed. Attempt to create artifact repository failed with error: {e}")
@@ -217,7 +242,6 @@ def deployModel(model_name, version_name, project_directory, number_pods, requir
 
     if verbose_logging : printInfo(f"Docker image memory size in gibibytes: {gibibytes_memory_size}")
     auto = 0
-    mem_util = memoryLimit
     calculated_mem_util = 0
     size = 0
 
@@ -303,26 +327,31 @@ def deployModel(model_name, version_name, project_directory, number_pods, requir
 
     if verbose_logging : printInfo("Create Service JSON  " + json.dumps(create_service_json))
 
-    create_service = requests.post('https://create-deployment-service-fgkue36c2q-uc.a.run.app', json = create_service_json, headers={'Authorization': api_token})
-    create_service_json = json.loads(create_service.text)
-    create_service_response = create_service_json["response"]
+    if not DEBUG:
+        create_service = requests.post('https://create-deployment-service-fgkue36c2q-uc.a.run.app', json = create_service_json, headers={'Authorization': api_token})
+        create_service_json = json.loads(create_service.text)
+        create_service_response = create_service_json["response"]
+
+        if(create_service.status_code != 200):
+            printError(f"ERROR. Deployment failed. Service creation failed with code {create_service.status_code} and message: {create_service_response}")
+            return(False)       
+        version_id = create_service_json["version_id"]
+    else:
+        create_service_json = createDeploymentService.mainTest(create_service_json, api_token)
+        print(create_service_json)
+        version_id = create_service_json[0]["version_id"]
 #endregion
     
-    if(create_service.status_code != 200):
-        printError(f"ERROR. Deployment failed. Service creation failed with code {create_service.status_code} and message: {create_service_response}")
-        return(False)
-    else:
-        version_id = create_service_json["version_id"]
-        print(f"\033[0;32mDeployment successful. Your new version ID is {version_id}, model ID is {model_id} and account ID is {account_id}. Please refer to our documentation for instructions on how to call it: https://docs.pyqai.com/pyq/guides/calling-a-deployment \033[00m" )
-        return(True)
+    print(f"\033[0;32mDeployment successful. Your new version ID is {version_id}, model ID is {model_id} and account ID is {account_id}. Please refer to our documentation for instructions on how to call it: https://docs.pyqai.com/pyq/guides/calling-a-deployment \033[00m" )
+    return(True)
 
 def main():
     parser = argparse.ArgumentParser()
     parser.add_argument("--model_name", help="The name you want to give your model", required=True)
     parser.add_argument("--version_name", help="The name you want to give this version of your model", required=True)
     parser.add_argument("--project_directory", help="The directory of your project. Put only what you need to run predictions using your model in it.", required=True)
-    parser.add_argument("--number_pods", help="The number of pods of your deployment if you are providing your own", required=False, default=2)
-    parser.add_argument("--keep_alive", help="How many hours the model should remain active without any usage. Anything greater than 48 hours may incur additional cost. You will experience a cold start once this time period expires. Defaults to 48", required=False, default=48, type=int)
+    parser.add_argument("--number_pods", help="The number of pods of your deployment if you are providing your own", required=False, default=1)
+    parser.add_argument("--keep_alive", help="How many hours the model should remain active without any usage. Anything greater than 8 hours may incur additional cost. You will experience a cold start once this time period expires. Defaults to 8", required=False, default=8, type=int)
     parser.add_argument("--requirements", help="Did you create your own requirements.txt in your project directory or should we make you one? Answer True or False. Default False.", required=False, default="False", choices=["True","False"])
     parser.add_argument("--memory_limit", help="The memory limit for your deployment in Gi if you are providing your own, else we will attempt to guess. Provide only the number with decimals.", required=False, default=-999.9, type=float)
     parser.add_argument("--dockerfile", help="Did you create your own Dockerfile in your project directory or should we make you one? Answer True or False. Default False.", required=False, default="False", choices=["True","False"])
