@@ -2,6 +2,7 @@ import requests
 import json
 import argparse
 import os
+import logging
 
 # NOTE: returns a list of pod names.
 # TODO: consider sending back the entire yaml? Maybe someone wants that? No status update here.
@@ -15,6 +16,7 @@ def get_pod_ids(model_name):
         account_name = configObj["account_name"]
         account_id = configObj["account_id"]
     except Exception as e:
+        logging.error(e, exc_info=True)
         print("ERROR. Unable to verify credentials; re-run pyqai-init to reset user credentials.")
         return 
 
@@ -26,6 +28,7 @@ def get_pod_ids(model_name):
         get_pods_content = get_pods_response['response']
         return get_pods_content
     except Exception as e:
+        logging.error(e, exc_info=True)
         print(f"ERROR. Unable to get pod names with exception: {e}")
         return
 
